All of lore.kernel.org
 help / color / mirror / Atom feed
* Patch "IB/hfi1: Check for QSFP presence before attempting reads" has been added to the 4.9-stable tree
@ 2018-03-18 16:01 gregkh
  0 siblings, 0 replies; only message in thread
From: gregkh @ 2018-03-18 16:01 UTC (permalink / raw)
  To: easwar.hariharan, alexander.levin, dennis.dalessandro, dledford,
	gregkh
  Cc: stable, stable-commits


This is a note to let you know that I've just added the patch titled

    IB/hfi1: Check for QSFP presence before attempting reads

to the 4.9-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     ib-hfi1-check-for-qsfp-presence-before-attempting-reads.patch
and it can be found in the queue-4.9 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.


>From foo@baz Sun Mar 18 16:55:33 CET 2018
From: Easwar Hariharan <easwar.hariharan@intel.com>
Date: Mon, 20 Mar 2017 17:25:42 -0700
Subject: IB/hfi1: Check for QSFP presence before attempting reads

From: Easwar Hariharan <easwar.hariharan@intel.com>


[ Upstream commit fb897ad315643e5dc1092a115b3cec914b66df9d ]

Attempting to read the status of a QSFP cable creates noise in the logs
and misses out on setting an appropriate Offline/Disabled Reason if the
cable is not plugged in. Check for this prior to attempting the read and
attendant retries.

Fixes: 673b975f1fba ("IB/hfi1: Add QSFP sanity pre-check")
Reviewed-by: Dennis Dalessandro <dennis.dalessandro@intel.com>
Signed-off-by: Easwar Hariharan <easwar.hariharan@intel.com>
Signed-off-by: Dennis Dalessandro <dennis.dalessandro@intel.com>
Signed-off-by: Doug Ledford <dledford@redhat.com>
Signed-off-by: Sasha Levin <alexander.levin@microsoft.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
 drivers/infiniband/hw/hfi1/chip.c |    7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

--- a/drivers/infiniband/hw/hfi1/chip.c
+++ b/drivers/infiniband/hw/hfi1/chip.c
@@ -9489,8 +9489,11 @@ static int test_qsfp_read(struct hfi1_pp
 	int ret;
 	u8 status;
 
-	/* report success if not a QSFP */
-	if (ppd->port_type != PORT_TYPE_QSFP)
+	/*
+	 * Report success if not a QSFP or, if it is a QSFP, but the cable is
+	 * not present
+	 */
+	if (ppd->port_type != PORT_TYPE_QSFP || !qsfp_mod_present(ppd))
 		return 0;
 
 	/* read byte 2, the status byte */


Patches currently in stable-queue which might be from easwar.hariharan@intel.com are

queue-4.9/ib-hfi1-check-for-qsfp-presence-before-attempting-reads.patch

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2018-03-18 16:02 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2018-03-18 16:01 Patch "IB/hfi1: Check for QSFP presence before attempting reads" has been added to the 4.9-stable tree gregkh

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.